@@ -1,5 +1,363 @@
 
+render_plot <- function(Object, Class, Stock=NULL, RMD=NULL, nsamp=3, nsim=200, nyears=50, 
+                        proyears=28, output_file=NULL, output_dir=getwd(), 
+                        quiet=TRUE, tabs=TRUE, title=NULL, date=NULL,
+                        plotPars =NULL, open=TRUE, dev=FALSE, parallel=TRUE) {
+  
+  SampCpars <- list() # empty list
+  
+  if (is.null(plotPars)) plotPars <- list(breaks=10, col="darkgray", axes=FALSE, 
+                                          cex.main=1, lwd=2)
+ 
+  if (class(Object) == "OM") {
+    nsim <- Object@nsim 
+    nyears <- Object@nyears
+    proyears <- Object@proyears
+    SampCpars <- if(length(Object@cpars)>0) SampCpars <- SampleCpars(Object@cpars, nsim, msg=FALSE)
+    set.seed(Object@seed)
+    Stock <- SubOM(Object, "Stock")
+    # Class <- "OM"
+  }
+  
+ 
+  if (Class == "Stock") {
+    if (is.null(title)) title <- "Stock Object Plots"
+    Pars <- SampleStockPars(Object, nsim, nyears, proyears, SampCpars, 
+                            msg=FALSE)
+    Pars$Name <- gsub(" ", "_", Object@Name)  
+  } else if (Class == "Fleet") {
+    if (is.null(title)) title <- "Fleet Object Plots"
+    if (class(Stock)!="Stock") 
+      stop("Must provide object of class 'Stock'", call. = FALSE)
+    StockPars <- SampleStockPars(Stock, nsim, nyears, proyears, SampCpars, 
+                                 msg=FALSE)
+    FleetPars <- SampleFleetPars(Object, StockPars, nsim, nyears, proyears,
+                                 SampCpars, msg=FALSE)
+  
+    Pars <- c(StockPars, FleetPars)
+    Pars$Name <- gsub(" ", "_", Object@Name)
+    Pars$CurrentYr <- Object@CurrentYr
+    Pars$MPA <- Object@MPA
+    
+  } else if (Class == "Obs") {
+    if (is.null(title)) title <- "Obs Object Plots"
+    ObsPars <- SampleObsPars(Object, nsim, cpars=SampCpars)
+    BMSY_B0bias <- array(rlnorm(nsim, 
+                                mconv(1, Object@BMSY_B0biascv), sdconv(1, Object@BMSY_B0biascv)), 
+                         dim = c(nsim))  # trial samples of BMSY relative to unfished  
+
+    ObsPars$BMSY_B0bias <- BMSY_B0bias
+    
+    Pars <- c(ObsPars)
+    
+  } else if (Class == "Imp") {
+    if (is.null(title)) title <- "Imp Object Plots"
+    ImpPars <- SampleImpPars(Object, nsim, cpars=SampCpars)
+    Pars <- c(ImpPars)
+  } else if (Class == "OM") {
+    if (is.null(title)) title <- "OM Object Plots"
+    message("Sampling Stock, Fleet, Obs, and Imp parameters")
+    StockPars <- SampleStockPars(SubOM(Object, "Stock"), nsim, nyears, proyears, SampCpars, msg=FALSE)
+    FleetPars <- SampleFleetPars(SubOM(Object, "Fleet"), StockPars, nsim, nyears, proyears, SampCpars, msg=FALSE)
+    ObsPars <- SampleObsPars(Object, nsim, cpars=SampCpars)
+    BMSY_B0bias <- array(rlnorm(nsim, 
+                                mconv(1, Object@BMSY_B0biascv), sdconv(1, Object@BMSY_B0biascv)), 
+                         dim = c(nsim))  # trial samples of BMSY relative to unfished  
+    
+    ObsPars$BMSY_B0bias <- BMSY_B0bias
+    ImpPars <- SampleImpPars(SubOM(Object, "Imp"), nsim, cpars=SampCpars)
+
+    Pars <- c(StockPars, FleetPars, ObsPars, ImpPars)
+    Pars$CurrentYr <- Object@CurrentYr
+    
+    if (!parallel) dopar <- FALSE
+    if (nsim>=48 & parallel) dopar <- TRUE
+    if (nsim<48& parallel) dopar <- FALSE
+    message("Running Historical Simulations")
+    Hist <- runMSE(Object, Hist=TRUE, silent=TRUE, parallel = dopar)
+    Pars$Hist <- Hist
+    Pars$Name <- "OM"
+    Pars$MPA <- Object@MPA
+    Pars$CurrentYr <- Object@CurrentYr
+  } else if (Class == "Hist") {
+    Pars <- list()
+    Pars$Hist <- Object
+    Pars$CurrentYr <- Object@Misc$CurrentYr
+    nyears <- length(Object@Data@Year)
+    if (is.null(title)) title <- "Historical Simulations"
+
+  } else {
+    stop("Object must be class 'Stock', 'Fleet', 'Obs', or 'Imp'", call.=FALSE)  
+  }
+  
+
+  if (Class !="Hist" & Class !="OM") {
+    Pars$Name <- gsub(" ", "_", Object@Name)  
+  } 
+  its <- sample(1:nsim, nsamp)
+  # Pars <<- Pars
+  Params <- list(
+    title = title,
+    Pars = Pars,
+    plotPars=plotPars,
+    tabs = tabs,
+    its = its,
+    nyears=nyears,
+    proyears=proyears,
+    date=NULL
+  )
+
+  outname <- paste0("_", RMD, ".html")
+  if (Class !="Hist" & Class !="OM") {
+    if (is.null(output_file)) output_file <- paste0(Pars$Name, outname)
+  } else {
+    if (is.null(output_file)) output_file <-  paste0(RMD, ".html")
+  }
+  message("Rendering HTML file")
+  
+  RMD <- paste0(RMD, ".Rmd")
+  if (dev) {
+    input <- file.path('inst/Rmd', Class, RMD) 
+  } else {
+    input <- file.path(system.file(package = 'DLMtool'),'Rmd', Class, RMD)  
+  }
+ 
+  knitr::knit_meta(class=NULL, clean = TRUE)
+  rend <- try(rmarkdown::render(input, params=Params,
+                                output_file=output_file,
+                                output_dir=output_dir,
+                                quiet=quiet), silent=TRUE)
+  if (class(rend) == "try-error") {
+    print(rend)
+  } else {
+    message("Rendered ", output_file, " in ", output_dir)
+    if (open) utils::browseURL(file.path(output_dir, output_file))
+  }
+}
+
 
+#' @method plot character
+#' @export
+#' @keywords internal
+plot.character <- function(x, Object, ...) {
+  plot.pars(x, Object, ...)  
+}
+
+#' @param Object An object of class `Stock` or `Fleet`
+#' @param Stock An object of class `Stock` required for `Fleet` parameters
+#' @rdname plot.Stock
+#' @export
+plot.pars <- function(x, Object, Stock=NULL, nsamp=3, nsim=200, nyears=50, 
+                      proyears=28, output_file=NULL, output_dir=getwd(), 
+                      quiet=TRUE, tabs=TRUE, title=NULL, date=NULL,
+                      plotPars =NULL, open=TRUE, dev=FALSE, ...) {
+  
+  StockDF <- data.frame(chr=c("M",
+                              "Growth",
+                              "Maturity",
+                              "Recruitment",
+                              "Spatial",
+                              "Depletion"),
+                        Class="Stock",
+                        stringsAsFactors = FALSE)
+  
+ FleetDF <- data.frame(chr=c("Effort",
+                              "Catchability",
+                              "MPA",
+                              "Selectivity"),
+                        Class="Fleet",
+                        stringsAsFactors = FALSE)
+  
+ DF <- dplyr::bind_rows(StockDF, FleetDF)
+  
+  if (!x %in% DF[,1]) 
+    stop("Invalid argument. Valid arguments are: ", paste0(DF[,1], sep=" "), call.=FALSE)
+  
+  Class <- DF$Class[match(x, DF[,1])]
+  if (class(Object) !="OM" & class(Object) != Class) 
+    stop("Incorrect class object for this parameter", call.=FALSE)
+  
+  
+  if (x == "M") x <- "NaturalMortality"
+  
+  render_plot(Object=Object, Class=Class, Stock=Stock, RMD=x, nsamp=nsamp, nsim=nsim, 
+              nyears=nyears, proyears=proyears,
+              output_file=output_file, output_dir=output_dir, quiet=quiet,
+              tabs=tabs, title=title, date=date,
+              plotPars=plotPars, open=open, dev=dev)
+}  
+
+
+
+#' @title Plot Operating Model Object
+#' 
+#' @description Generate HTML reports with plots of operating model components ("Stock",
+#' "Fleet", "Obs", and "Imp"), the historical simulations ("Hist"), or the complete OM ("OM").
+#' 
+#' The individual component plots of objects of class `Stock` and `Fleet` can also be generated by 
+#' using the generic `plot.pars` function. See Examples below.
+#' 
+#' @param x An object of class `Stock`, `Fleet`, `Obs`, `Imp`, `Hist`, or `OM`, OR one 
+#' of the following character strings for `Object` of class `Stock`: "M", "Growth", "Maturity", "Recruitment", "Spatial",
+#' or "Depletion" and for `Object` of class `Fleet`: "Effort", "Catchability", "MPA",
+#' and "Selectivity".
+#' @param nsamp The number of random samples to show in the plot
+#' @param nsim The number of simulations (only used for objects not of class `OM`)
+#' @param nyears The number of historical years (only used for objects not of class `OM`)
+#' @param proyears The number of projection years (only used for objects not of class `OM`)
+#' @param output_file Name of the output html file (without file extension)
+#' @param output_dir Output directory. Defaults to `getwd()`
+#' @param quiet An option to suppress printing of the pandoc command line 
+#' @param tabs Include tabs in the HTML file?
+#' @param title Optional title for the markdown report
+#' @param date Optional date for the markdown report
+#' @param plotPars A named list with options for plots:
+#' \itemize{
+#'   \item breaks - numeric. Number of breaks in histograms.
+#'   \item col - character. Color of histograms.
+#'   \item axes - logical. Include axes in histogram?
+#'   \item cex.main - numeric. Size of main title in plots.
+#'   \item lwd - numeric. Line width for time-series plots.
+#' }
+#' @param open Logical. Open the html file?
+#' @param dev Logical. For development use only.
+#' @param ... Not used
+#'
+#' @method plot Stock
+#' @export
+#' @examples
+#' \dontrun{
+#' # Plot Stock Object:
+#' Stock <- DLMtool::Albacore
+#' plot(Stock)
+#' 
+#' # Individual plots:
+#' plot("M", Stock)
+#' plot("Growth", Stock)
+#' plot("Maturity", Stock)
+#' plot("Recruitment", Stock)
+#' plot("Spatial", Stock)
+#' plot("Depletion", Stock)
+#' 
+#' # Plot Fleet Object
+#' Fleet <- DLMtool::Generic_DecE
+#' plot(Fleet, Stock)
+#' 
+#' # Individual plots:
+#' plot("Effort", Fleet, Stock)
+#' plot("Catchability", Fleet, Stock)
+#' plot("MPA", Fleet, Stock)
+#' plot("Selectivity", Fleet, Stock)
+#' 
+#' 
+#' # Plot Obs Object
+#' Obs <- DLMtool::Imprecise_Unbiased
+#' plot(Obs)
+#' 
+#' # Plot Imp Object
+#' Imp <- DLMtool::Overages
+#' plot(Imp)
+#' 
+#' 
+#' # Plot Hist Object
+#' OM <- DLMtool::testOM 
+#' Hist <- runMSE(OM, Hist=TRUE)
+#' plot(Hist)
+#' 
+#' # Plot OM Object
+#' plot(OM)
+#' }
+plot.Stock <- function(x, nsamp=3, nsim=200, nyears=50, 
+                       proyears=28, output_file=NULL, output_dir=getwd(), 
+                       quiet=TRUE, tabs=TRUE, title=NULL, date=NULL,
+                       plotPars =NULL, open=TRUE, dev=FALSE, ...){
+  
+  render_plot(Object=x, Class="Stock", RMD='Stock', nsamp=nsamp, nsim=nsim, 
+              nyears=nyears, proyears=proyears,
+              output_file=output_file, output_dir=output_dir, quiet=quiet,
+              tabs=tabs, title=title, date=date,
+              plotPars=plotPars, open=open, dev=dev)
+}
+
+
+#' @rdname plot.Stock
+#' @method plot Fleet
+#' @export
+plot.Fleet <- function(x, Stock=NULL, nsamp=3, nsim=200, nyears=50, 
+                       proyears=28, output_file=NULL, output_dir=getwd(), 
+                       quiet=TRUE, tabs=TRUE, title=NULL, date=NULL,
+                       plotPars =NULL, open=TRUE, dev=FALSE, ...){
+  if (class(Stock) !="Stock" & class(x) !="OM")
+    stop("Must provide object of class 'Stock'")
+  
+  render_plot(Object=x, Class="Fleet", Stock=Stock, RMD='Fleet', nsamp=nsamp, nsim=nsim, 
+              nyears=nyears, proyears=proyears,
+              output_file=output_file, output_dir=output_dir, quiet=quiet,
+              tabs=tabs, title=title, date=date,
+              plotPars=plotPars, open=open, dev=dev)
+}
+
+#' @rdname plot.Stock
+#' @method plot Obs
+#' @export
+plot.Obs <- function(x, nsamp=3, nsim=200, nyears=50, 
+                       proyears=28, output_file=NULL, output_dir=getwd(), 
+                       quiet=TRUE, tabs=TRUE, title=NULL, date=NULL,
+                       plotPars =NULL, open=TRUE, dev=FALSE, ...){
+  
+  render_plot(Object=x, Class="Obs", Stock=NULL, RMD='Obs', nsamp=nsamp, nsim=nsim, 
+              nyears=nyears, proyears=proyears,
+              output_file=output_file, output_dir=output_dir, quiet=quiet,
+              tabs=tabs, title=title, date=date,
+              plotPars=plotPars, open=open, dev=dev)
+}
+
+#' @rdname plot.Stock
+#' @method plot Imp
+#' @export
+plot.Imp <- function(x, nsamp=3, nsim=200, nyears=50, 
+                     proyears=28, output_file=NULL, output_dir=getwd(), 
+                     quiet=TRUE, tabs=TRUE, title=NULL, date=NULL,
+                     plotPars =NULL, open=TRUE, dev=FALSE, ...){
+  
+  render_plot(Object=x, Class="Imp", Stock=NULL, RMD='Imp', nsamp=nsamp, nsim=nsim, 
+              nyears=nyears, proyears=proyears,
+              output_file=output_file, output_dir=output_dir, quiet=quiet,
+              tabs=tabs, title=title, date=date,
+              plotPars=plotPars, open=open, dev=dev)
+}
+
+#' @rdname plot.Stock
+#' @method plot Hist
+#' @export
+plot.Hist <- function(x, nsamp=3, nsim=200, nyears=50, 
+                      proyears=28, output_file=NULL, output_dir=getwd(), 
+                      quiet=TRUE, tabs=TRUE, title=NULL, date=NULL,
+                      plotPars =NULL, open=TRUE, dev=FALSE, ...) {
+  render_plot(Object=x, Class="Hist", Stock=NULL, RMD='Hist', nsamp=nsamp, nsim=nsim, 
+              nyears=nyears, proyears=proyears,
+              output_file=output_file, output_dir=output_dir, quiet=quiet,
+              tabs=tabs, title=title, date=date,
+              plotPars=plotPars, open=open, dev=dev)
+}
+
+#' @rdname plot.Stock
+#' @method plot OM
+#' @export
+plot.OM <- function(x, nsamp=3, nsim=200, nyears=50, 
+                    proyears=28, output_file=NULL, output_dir=getwd(), 
+                    quiet=TRUE, tabs=TRUE, title=NULL, date=NULL,
+                    plotPars =NULL, open=TRUE, dev=FALSE, ...) {
+  render_plot(Object=x, Class="OM", Stock=NULL, RMD='OM', nsamp=nsamp, nsim=nsim, 
+              nyears=nyears, proyears=proyears,
+              output_file=output_file, output_dir=output_dir, quiet=quiet,
+              tabs=tabs, title=title, date=date,
+              plotPars=plotPars, open=open, dev=dev)
+  
+  
+}
+
+#### --- Old Code ----------------------------------------------------------####
 #' Plot the Historical Spatial Closures
 #'
 #' @param OM An object of class OM
@@ -9,6 +367,7 @@
 #' @author A. Hordyk
 #'
 #' @examples
+#' \dontrun{
 #' OM <- new("OM", Albacore, Generic_Fleet, Perfect_Info, Perfect_Imp)
 #' 
 #' ## 50% of Area 1 was closed 30 years ago 
@@ -20,8 +379,10 @@
 #' 
 #' OM@MPA <- matrix(c(cl1, cl2, cl3), ncol=3, byrow=TRUE)
 #' plotMPA(OM)
+#' }
 #' 
 plotMPA <- function(OM, sim=NA) {
+  .Deprecated('plot("MPA", Fleet, Stock')
   if (class(OM)!="OM") stop("Object must be class 'OM'")
   if (class(OM)=="OM") {
     proyears <- OM@proyears
@@ -94,6 +455,7 @@ plotMPA <- function(OM, sim=NA) {
 #' @export
 #'
 plotSelect <- function(OM, Pars=NULL, pyears=4, sim=NA, type="l") {
+  .Deprecated('plot("Selectivity", Fleet, Stock')
   if (class(OM) != "OM") stop("Object must be class 'OM' ")
   nsim <- OM@nsim
   if (!is.na(sim)) OM@nsim <- nsim <- max(10, sim) # OM@nsim 
@@ -110,6 +472,7 @@ plotSelect <- function(OM, Pars=NULL, pyears=4, sim=NA, type="l") {
   if (pyears > 1) gr <- c(2, pyears)
   if (pyears == 1) gr <- c(1, 2)
   op <- par(mfcol=gr, bty="l", las=1, mar=c(3,3,2,0), oma=c(3,3,2,1), xpd=NA)
+  on.exit(par(op))
   
   for (yr in yr.vert) {
     # plot vulnerability & selection at age
@@ -156,7 +519,6 @@ plotSelect <- function(OM, Pars=NULL, pyears=4, sim=NA, type="l") {
     
   }
   mtext(side=3, paste0("Selection and Retention curves for simulation: ", sim),  outer=TRUE)
-  on.exit(par(op))
   
   invisible(list(V=Pars$V, V2=Pars$V2 ,retA=Pars$retA, DR=Pars$DR, 
                  Fdisc=Pars$Fdisc, sim=sim))
@@ -172,8 +534,12 @@ plotSelect <- function(OM, Pars=NULL, pyears=4, sim=NA, type="l") {
 #' @author A. Hordyk
 #' @export
 #'
-#' @examples plotM(Albacore)
+#' @examples 
+#' \dontrun{
+#' plotM(Albacore)
+#' }
 plotM <- function(Stock, nsim=5) {
+  .Deprecated('plot("M", Stock')
   if (class(Stock) != "Stock" && class(Stock) != "OM") stop("Must supply object of class 'Stock' or 'OM'")
   
   nyears <- 30
@@ -200,7 +566,6 @@ plotM <- function(Stock, nsim=5) {
   op <- par(no.readonly = TRUE)
   on.exit(par(op))
   
-  
   par(mfrow=c(3,3), bty="l", las=1, mar=c(3,3,2,1), oma=c(2,2,0,0))
   ylim <- c(0, max(M_at_age))
   lwd <- 2
@@ -269,9 +634,9 @@ hist2 <- function(x, col, axes=FALSE, main="", breaks=10,cex.main=1) {
 
 
 
-#' @method plot Stock
-#' @export
-plot.Stock <- function(x, ...)  plotStock(x, ...)
+# #' @method plot Stock
+# #' @export
+# plot.Stock <- function(x, ...)  plotStock(x, ...)
 
 #' Plot the Stock object parameters 
 #' 
@@ -295,6 +660,7 @@ plot.Stock <- function(x, ...)  plotStock(x, ...)
 plotStock <- function(x, nsamp=3, nsim=500, nyears=50, proyears=28, 
                       col="darkgray", breaks=10, lwd=2, ask=FALSE, incVB=TRUE, ...) {
   Stock <- x 
+  .Deprecated('plot.Stock')
   SampCpars <- list() # empty list 
   if (class(Stock) == "OM") {
     Stock <- updateMSE(x) 
@@ -333,6 +699,7 @@ plotStock <- function(x, nsamp=3, nsim=500, nyears=50, proyears=28,
   # layout.show(m)
   # stop()
   op <- par(mar = c(2, 1, 3, 1), oma=c(1,2,4,1), ask=FALSE, las=1)
+  on.exit(par(op))
   
   # Row 1 -- Natural Mortality ---- 
   hist2(M, col=col, axes=FALSE, main="M", breaks=breaks)
@@ -507,16 +874,15 @@ plotStock <- function(x, nsamp=3, nsim=500, nyears=50, proyears=28,
     title("Sampled length-at-age curves", outer=TRUE, cex.main=2)
   }
   
-  on.exit(par(op))
-  
+  invisible(StockPars)
 }
 
 
 
 
-#' @method plot Fleet
-#' @export
-plot.Fleet <- function(x, ...)  plotFleet(x, ...)
+# #' @method plot Fleet
+# #' @export
+# plot.Fleet <- function(x, ...)  plotFleet(x, ...)
 
 #' Plot the Fleet object parameters 
 #' 
@@ -534,7 +900,7 @@ plot.Fleet <- function(x, ...)  plotFleet(x, ...)
 #' @export 
 plotFleet <- function(x, Stock=NULL, nsamp=3, nsim=500, proyears=28, col="darkgray", 
                       breaks=10, lwd=2, ...) { 
-  
+  .Deprecated('plot.Fleet')
   Fleet <- updateMSE(x) # add missing slots with default values 
   SampCpars <- list() # empty list 
   nyears <- Fleet@nyears
@@ -576,7 +942,8 @@ plotFleet <- function(x, Stock=NULL, nsamp=3, nsim=500, proyears=28, col="darkgr
   heights=c(1,0.2, 1,0.3, 1, 0.3, 1, 0.3, 1))
   # layout.show(m)				   
   
-  op <- par(mar = c(2,2, 2, 1), oma=c(2,2,4,1), las=1)  
+  op <- par(mar = c(2,2, 2, 1), oma=c(2,2,4,1), las=1)
+  on.exit(par(op))	 
   hist2(Esd, col=col, axes=FALSE, main="Esd", breaks=breaks)
   abline(v=Esd[its], col=1:nsamp, lwd=lwd)
   axis(side=1) 
@@ -664,13 +1031,13 @@ plotFleet <- function(x, Stock=NULL, nsamp=3, nsim=500, proyears=28, col="darkgr
   # om <- new("OM", Stock, Fleet, Perfect_Info, Perfect_Imp)
   # plotSelect(om)
   
-  on.exit(par(op))	  
+  invisible(FleetPars)
 }
 
 
-#' @method plot Obs
-#' @export
-plot.Obs <- function(x, ...)  plotObs(x, ...)
+# #' @method plot Obs
+# #' @export
+# plot.Obs <- function(x, ...)  plotObs(x, ...)
 
 #' Plot the Observation object parameters 
 #' 
@@ -689,7 +1056,7 @@ plot.Obs <- function(x, ...)  plotObs(x, ...)
 #' @export 
 plotObs <- function(x, nsim=500, nyears=50, 
                     col="darkgray", breaks=10, ...) {
-  
+  .Deprecated('plot.Obs')
   Obs <- x
   SampCpars <- list() # empty list 
   if (class(Obs) == "OM") {
@@ -714,6 +1081,7 @@ plotObs <- function(x, nsim=500, nyears=50,
   # === Non time series ==================================================================== 
   cex.main <- 0.5
   op <- par(mfrow=c(4,4),mai=c(0.6,0.6,0.25,0.01),omi=c(0.01,0.01,0.4,0.01))
+  on.exit(par(op))	 
   
   hist2(CAA_nsamp,col=col,axes=FALSE, main="No. annual catch-at-age obs (CAA_samp)", breaks=breaks,cex.main=cex.main)
   axis(side=1) 
@@ -822,14 +1190,13 @@ plotObs <- function(x, nsim=500, nyears=50,
   if (!is.na(Obs@Name)) mtext(paste0("Observation time series plots for observation object ",Obs@Name),3,outer=T,line= 0.7,font=2)
   if (is.na(Obs@Name)) mtext(paste0("Observation time series plots for observation object "),3,outer=T,line= 0.7,font=2)
   
-  on.exit(par(op))
-  
+  invisible(ObsPars)
 }
 
 
-#' @method plot Imp
-#' @export
-plot.Imp <- function(x, ...)  plotImp(x, ...)
+# #' @method plot Imp
+# #' @export
+# plot.Imp <- function(x, ...)  plotImp(x, ...)
 
 #' Plot the Implementation object parameters 
 #' 
@@ -848,6 +1215,8 @@ plot.Imp <- function(x, ...)  plotImp(x, ...)
 #' @export 
 plotImp<-function(x,nsim=500, nyears=50, 
                   col="darkgray", breaks=10, ...){
+  
+  .Deprecated('plot.Imp')
   Imp <- x
   if (class(Imp) == "OM") {
     if (is.finite(Imp@nyears)) nyears <- Imp@nyears
@@ -864,7 +1233,7 @@ plotImp<-function(x,nsim=500, nyears=50,
   its <- sample(1:nsim, nsamp)
   
   op <- par(mfrow=c(4,3),mai=c(0.6,0.6,0.2,0.01),omi=c(0.01,0.01,0.4,0.01))
-  
+  on.exit(par(op))	 
   
   ObsTSplot(TACFrac,TACSD,nyears,labs=c("Fraction of TAC (TACFrac)",
                                         "TAC error (TACSD)","TAC discrepancy for three samples",
@@ -880,8 +1249,7 @@ plotImp<-function(x,nsim=500, nyears=50,
   
   mtext(paste0("Implementation error time series plots for implementation object ",Imp@Name),3,outer=T,line= 0.7,font=2)
   
-  on.exit(par(op))
-  
+  invisible(ImpPars)
 }
 
 
@@ -923,109 +1291,109 @@ ObsTSplot<-function(Cbias,Csd,nyears,labs, breaks, its, nsamp, col){
 #' @param head Character. Heading for rmd file. Default is '##' (second level heading)
 #' @param ...  Optional additional arguments passed to \code{plot}
 #' @rdname plot-OM
-#' @method plot OM 
 #' @author T. Carruthers
 #' @export 
-plot.OM <-function(x, rmd=FALSE, head="##", ...){
-  op <- par(no.readonly = TRUE)
-  on.exit(par(op))
-  if (class(x) == "OM") {
-    OM <- updateMSE(x) # update and add missing slots with default values
-    out<-runMSE(OM,Hist=T, ...)
-    nsim<-OM@nsim
-    nyears<-OM@nyears
-    if (rmd) {
-      cat('\n')
-      cat('\n')
-      cat(head, 'Stock Object')
-      cat('\n')
-    }
-    plotStock(OM)
-    if (rmd) {
-      cat('\n')
-      cat('\n')
-      cat(head, 'Fleet Object')
-      cat('\n')
-    }
-    plotFleet(OM)
-    if (rmd) {
-      cat('\n')
-      cat('\n')
-      cat(head, 'Obs Object')
-      cat('\n')
-    }
-    plotObs(OM)
-    if (rmd) {
-      cat('\n')
-      cat('\n')
-      cat(head, 'Imp Object')
-      cat('\n')
-    }
-    plotImp(OM)
-    yrlab<-OM@CurrentYr-((nyears-1):0)
-  } else if (class(x) == "Hist") {
-    out <- x 
-    nyears <- dim(out@TSdata[[1]])[2]
-    nsim <- dim(out@TSdata[[1]])[1]
-    yrlab<-nyears-((nyears-1):0)
-  } else stop("argument must be class 'OM' or 'Hist' ")
-  
-  if (rmd) {
-    cat('\n')
-    cat('\n')
-    cat(head, 'OM Simulations')
-    cat('\n')
-  }
-  
-  # Time series
-  par(mfrow=c(4,2),mai=c(0.7,0.7,0.05,0.05),omi=c(0.01,0.01,0.3,0.01))
-  
-  # SSB
-  TSplot(yrlab,out@TSdata$SSB,xlab="Historical year",ylab="Spawning biomass")
-  
-  # Depletion
-  TSplot(yrlab,out@TSdata$SSB/rep(out@Ref$SSB0,each=nyears),xlab="Historical year",ylab="Stock depletion (SSB)")
-  
-  # Apical F
-  FM<-t(out@TSdata$Find*out@OM$qs)
-  FM[FM > out@OM$maxF[1]] <- out@OM$maxF[1] # add maxF constraint
-  TSplot(yrlab,t(FM),xlab="Historical year",ylab="Fishing mortality rate (apical)")
-  
-  # Catches
-  TSplot(yrlab,out@TSdata$Catch,xlab="Historical year",ylab="Annual catches")
-  
-  # Recruitment
-  TSplot(yrlab,out@TSdata$Rec,xlab="Historical year",ylab="Recruitment")
-  
-  # SSB-Rec
-  TSplot(x=out@TSdata$SSB[,2:nyears],y=out@TSdata$Rec[,2:nyears],
-         xlab="Spawning biomass",ylab="Recruitment",mat=F,type='p')
-  
-  F_FMSY<-FM/matrix(out@Ref$FMSY, nrow=nyears, ncol=nsim, byrow=TRUE)
-  B_BMSY<-out@TSdata$SSB/matrix(out@Ref$SSBMSY, nrow=nsim, ncol=nyears)
-  
-  TSKplot(B_BMSY,t(F_FMSY),yrlab)
-  
-  # Age vulnerability
-  maxage<-dim(out@AtAge$Select)[2]
-  colors <- c("green","blue","grey45")
-  for (x in 1:3) {
-    Zvals <- t(out@AtAge$Select[x,,1:nyears])
-    if(sd(Zvals, na.rm=TRUE) != 0) {
-      if (x==1)contour(x=yrlab,y=1:maxage,z=Zvals,levels=c(0.25,0.75),col=colors[x],drawlabels=F,lwd=c(1,2))
-      if (x!=1)contour(x=yrlab,y=1:maxage,z=Zvals,levels=c(0.25,0.75),col=colors[x],drawlabels=F, add=T,lwd=c(1,2))
-    }
-  }
-  
-  legend('topright',legend=c(paste("Simulation",1:3)),text.col=c("green","blue","grey45"),bty='n')
-  legend('topleft',legend="Age vulnerability (0.25, 0.75)",bty='n')
-  
-  mtext("Historical year", 1, line = 2.5, cex = 1)
-  mtext("Age", 2, line = 2.3, cex = 1)
-  
-  if (class(x) == 'OM') mtext(paste0("Time series plots for operating model ",OM@Name),3,outer=T,line= 0.2,font=2)
-  
-  return(invisible(out))
+plotOM <-function(x, rmd=FALSE, head="##", ...){
+  .Deprecated('plot.OM')
+ op <- par(no.readonly = TRUE)
+ on.exit(par(op))
+ if (class(x) == "OM") {
+   OM <- updateMSE(x) # update and add missing slots with default values
+   out<-runMSE(OM,Hist=T, ...)
+   nsim<-OM@nsim
+   nyears<-OM@nyears
+   if (rmd) {
+     cat('\n')
+     cat('\n')
+     cat(head, 'Stock Object')
+     cat('\n')
+   }
+   plotStock(OM)
+   if (rmd) {
+     cat('\n')
+     cat('\n')
+     cat(head, 'Fleet Object')
+     cat('\n')
+   }
+   plotFleet(OM)
+   if (rmd) {
+     cat('\n')
+     cat('\n')
+     cat(head, 'Obs Object')
+     cat('\n')
+   }
+   plotObs(OM)
+   if (rmd) {
+     cat('\n')
+     cat('\n')
+     cat(head, 'Imp Object')
+     cat('\n')
+   }
+   plotImp(OM)
+   yrlab<-OM@CurrentYr-((nyears-1):0)
+ } else if (class(x) == "Hist") {
+   out <- x 
+   nyears <- dim(out@TSdata[[1]])[2]
+   nsim <- dim(out@TSdata[[1]])[1]
+   yrlab<-nyears-((nyears-1):0)
+ } else stop("argument must be class 'OM' or 'Hist' ")
+ 
+ if (rmd) {
+   cat('\n')
+   cat('\n')
+   cat(head, 'OM Simulations')
+   cat('\n')
+ }
+ 
+ # Time series
+ par(mfrow=c(4,2),mai=c(0.7,0.7,0.05,0.05),omi=c(0.01,0.01,0.3,0.01))
+ 
+ # SSB
+ TSplot(yrlab,out@TSdata$SSB,xlab="Historical year",ylab="Spawning biomass")
+ 
+ # Depletion
+ TSplot(yrlab,out@TSdata$SSB/rep(out@Ref$SSB0,each=nyears),xlab="Historical year",ylab="Stock depletion (SSB)")
+ 
+ # Apical F
+ FM<-t(out@TSdata$Find*out@OM$qs)
+ FM[FM > out@OM$maxF[1]] <- out@OM$maxF[1] # add maxF constraint
+ TSplot(yrlab,t(FM),xlab="Historical year",ylab="Fishing mortality rate (apical)")
+ 
+ # Catches
+ TSplot(yrlab,out@TSdata$Catch,xlab="Historical year",ylab="Annual catches")
+ 
+ # Recruitment
+ TSplot(yrlab,out@TSdata$Rec,xlab="Historical year",ylab="Recruitment")
+ 
+ # SSB-Rec
+ TSplot(x=out@TSdata$SSB[,2:nyears],y=out@TSdata$Rec[,2:nyears],
+        xlab="Spawning biomass",ylab="Recruitment",mat=F,type='p')
+ 
+ F_FMSY<-FM/matrix(out@Ref$FMSY, nrow=nyears, ncol=nsim, byrow=TRUE)
+ B_BMSY<-out@TSdata$SSB/matrix(out@Ref$SSBMSY, nrow=nsim, ncol=nyears)
+ 
+ TSKplot(B_BMSY,t(F_FMSY),yrlab)
+ 
+ # Age vulnerability
+ maxage<-dim(out@AtAge$Select)[2]
+ colors <- c("green","blue","grey45")
+ for (x in 1:3) {
+   Zvals <- t(out@AtAge$Select[x,,1:nyears])
+   if(sd(Zvals, na.rm=TRUE) != 0) {
+     if (x==1)contour(x=yrlab,y=1:maxage,z=Zvals,levels=c(0.25,0.75),col=colors[x],drawlabels=F,lwd=c(1,2))
+     if (x!=1)contour(x=yrlab,y=1:maxage,z=Zvals,levels=c(0.25,0.75),col=colors[x],drawlabels=F, add=T,lwd=c(1,2))
+   }
+ }
+ 
+ legend('topright',legend=c(paste("Simulation",1:3)),text.col=c("green","blue","grey45"),bty='n')
+ legend('topleft',legend="Age vulnerability (0.25, 0.75)",bty='n')
+ 
+ mtext("Historical year", 1, line = 2.5, cex = 1)
+ mtext("Age", 2, line = 2.3, cex = 1)
+ 
+ if (class(x) == 'OM') mtext(paste0("Time series plots for operating model ",OM@Name),3,outer=T,line= 0.2,font=2)
+ 
+ return(invisible(out))
 }
 
 TSplot<-function(x,y,xlab=NA,ylab=NA,zeroy=T,incx=T,incy=T,type='l',mat=T){
