@@ -200,13 +200,6 @@ NULL
 "SimulatedData"
 
 
-#'  SimulatedData Data
-#'
-#'  An object of class Data
-#'
-"SimulatedData"
-
-
 #'  StockDescription 
 #'
 #'  A data.frame with description of slots for class Stock
@@ -249,6 +242,13 @@ NULL
 "OMDescription"
 
 
+#'  MSEDescription 
+#'
+#'  A data.frame with description of slots for class MSE
+#'
+"MSEDescription"
+
+
 #'  LHdatabase 
 #'
 #'  Database from the FishLife package with predicted life-history parameters for all species on FishBase
